# Dronefly core

This is an incomplete rewrite of [Dronefly](https://dronefly.readthedocs.io)
Discord bot's core components. We're not yet making version guarantees until
it is more usable.

# Related packages

## Dronefly command-line client

The [dronefly-cli](https://github.com/dronefly-garden/dronefly-cli) command-line
client will provide a standalone text user interface that can perform a usable
subset of Dronefly Discord bot's capabilities, built solely with Dronefly core.

## Dronefly Discord bot

Dronefly Discord bot brings [iNaturalist](https://www.inaturalist.org) taxa,
observations, and other data from the site into conversations on the
[Discord](https://discord.com) chat platform.
